@@ -1,6 +1,7 @@
 """
 File for storing constant data for sql-tools library.
 """
+
 from sqlite3 import sqlite_version
 
 # Data
@@ -11,17 +12,14 @@ __stopTime__ = None
 __status__ = None
 __jsonFormat__ = "Error in JSON file or it may not in the specified format.\nFormat:\n\t{\n\t\t<database>:\n\t\t{\n\t\t\t<table name>:\n\t\t\t[\n\t\t\t\t<commands>\n\t\t\t]\n\t\t}\n\t}"
 __history__ = []
+__processId__ = None
 
-
-# FOR "execute.py"
 __databPath__ = []
 
-# FOR "databFuncs.py"
 __copyCount__ = 0
 
 # Global constants
-__version__ = "SQL-Tools version: 0.2.4"
+__version__ = f"SQL-Tools (sqlite) version: {sqlite_version}"
 
 if __name__ == "__main__":
-    print("Contants for SQL-Tools library.")
-    input()
+    print("Contants for SQL-Tools (sqlite) library.")
